pub struct NewWorkerResult {
pub worker_id: WorkerID,
pub old_worker_id: Option<WorkerID>,
pub was_playing_sequence: bool,
}Expand description
The result of calling AudioNodePool::new_worker.
Fields
worker_id: WorkerIDThe new ID of the worker assigned to play this sequence.
old_worker_id: Option<WorkerID>The ID that was previously assigned to this worker.
was_playing_sequence: boolIf this is true, then this worker was already playing a sequence, and that
sequence has been stopped.