SpatialBasicChain

Struct SpatialBasicChain 

pub struct SpatialBasicChain {
    pub spatial_basic: SpatialBasicNode,
}
A default FxChain for 3D game audio.

This chain contains a single SpatialBasic node.

Fields

spatial_basic: SpatialBasicNode

Implementations

Source

impl SpatialBasicChain

pub fn set_params<B: AudioBackend>( &mut self, params: SpatialBasicNode, time: Option<EventInstant>, node_ids: &[NodeID], cx: &mut FirewheelCtx<B>, )

Set the parameters of the spatial basic node.

  • params - The new parameters.
  • time - The instant these new parameters should take effect. If this is None, then the parameters will take effect as soon as the node receives the event.