VolumePanChain

Struct VolumePanChain 

pub struct VolumePanChain {
    pub volume_pan: VolumePanNode,
    pub config: VolumeNodeConfig,
}
A default FxChain for 2D game audio.

This chain contains a single VolumePan node.

Fields

volume_pan: VolumePanNodeconfig: VolumeNodeConfig

Implementations

Source

impl VolumePanChain

pub fn set_params<B: AudioBackend>( &mut self, params: VolumePanNode, time: Option<EventInstant>, node_ids: &[NodeID], cx: &mut FirewheelCtx<B>, )

Set the parameters of the volume pan node.

  • params - The new parameters.
  • time - The instant these new parameters should take effect. If this is None, then the parameters will take effect as soon as the node receives the event.